import os

# Define the path to the file containing the verbs using absolute path
current_dir = os.path.dirname(os.path.abspath(__file__))  # Get current directory of this file
verb_file_path = os.path.join(current_dir, 'verbs.txt')   # Join directory with file name

# Function to load verbs from the file
def load_verbs():
    with open(verb_file_path, 'r', encoding='utf-8') as file:
        return [line.strip() for line in file]

# Fetch all verbs when imported
verbs = load_verbs()



from setuptools import setup, find_packages

setup(
    name="punjabi_verbs",              # Name of your package
    version="0.1",                     # Initial version
    description="A package for Punjabi verbs",  # Short description
    packages=find_packages(),          # Automatically find packages
    include_package_data=True,         # Include non-code files (like verbs.txt)
    install_requires=[],               # List any dependencies here
    author="Muhammad Shoaib Tahir",                # Your name
    author_email="shoaibtahir410@gmail.com",  # Your email
    url="https://github.com/MuhammadshoaibTahir/punjabiverbs.git",  # Link to your repository
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',           # Python version requirement
)
